diff --git a/modules/access/dshow/dshow.cpp b/modules/access/dshow/dshow.cpp
index f5c60ef..717f3d8 100644
--- a/modules/access/dshow/dshow.cpp
+++ b/modules/access/dshow/dshow.cpp
@@ -34,6 +34,7 @@
 #include <inttypes.h>
 #include <list>
 #include <string>
+#include <sstream>
 #include <assert.h>
 
 #define VLC_MODULE_LICENSE VLC_LICENSE_GPL_2_PLUS
@@ -726,6 +727,15 @@ static int DemuxOpen( vlc_object_t *p_this )
                 /* This is in RGB format
             http://msdn.microsoft.com/en-us/library/dd407253%28VS.85%29.aspx?ppud=4
                  */
+                msg_Dbg( p_this, "DShow format: RGB24" );
+                fmt.video.i_rmask = 0x00ff0000;
+                fmt.video.i_gmask = 0x0000ff00;
+                fmt.video.i_bmask = 0x000000ff;
+            }
+
+            if( p_stream->i_fourcc == VLC_CODEC_RGB32 )
+            {
+                msg_Dbg( p_this, "DShow format: RGB32" );
                 fmt.video.i_rmask = 0x00ff0000;
                 fmt.video.i_gmask = 0x0000ff00;
                 fmt.video.i_bmask = 0x000000ff;
@@ -1868,6 +1878,15 @@ static int Demux( demux_t *p_demux )
 
             if( i_pts > VLC_TS_INVALID )
                 es_out_Control( p_demux->out, ES_OUT_SET_PCR, i_pts );
+
+            std::stringstream dsstream;
+
+            for( int i = 0; i < 12; ++i )
+                dsstream << "0x" << std::hex << ( unsigned ) p_block->p_buffer[ i ] << " ";
+
+            std::string dsstring = dsstream.str();
+            msg_Dbg( p_demux, "Block buffer: %s", dsstring.c_str() );
+
             es_out_Send( p_demux->out, p_stream->p_es, p_block );
 
             i_samples--;
